==> haskell-safecopy-0.10.2-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 safecopy
version:              0.10.2
visibility:           public
id:                   safecopy-0.10.2-5QP7PokOwOW9ByOGoQ6uzX
key:                  safecopy-0.10.2-5QP7PokOwOW9ByOGoQ6uzX
license:              LicenseRef-PublicDomain
maintainer:           Lemmih <lemmih@gmail.com>
author:               David Himmelstrup, Felipe Lessa
homepage:             https://github.com/acid-state/safecopy
synopsis:             Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.

category:             Data, Parsing
abi:                  b13272ee99fc8d019e263636b4f7d141
exposed:              True
exposed-modules:      Data.SafeCopy Data.SafeCopy.Internal
hidden-modules:
    Data.SafeCopy.Instances Data.SafeCopy.SafeCopy Data.SafeCopy.Derive

import-dirs:          /usr/lib/ghc-8.8.3/site-local/safecopy-0.10.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/safecopy-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/safecopy-0.10.2
hs-libraries:         HSsafecopy-0.10.2-5QP7PokOwOW9ByOGoQ6uzX
depends:
    array-0.5.4.0 base-4.13.0.0 bytestring-0.10.10.0
    cereal-0.5.8.1-4ELvUVAvdXS1XtXORHyQWs containers-0.6.2.1
    generic-data-0.8.3.0-I26PFzFt6ga5QA4tf77LXa
    old-time-1.1.0.3-LFCo3WvTzIJ9XV4spupeM9 template-haskell-2.15.0.0
    text-1.2.4.0 time-1.9.3 transformers-0.5.6.2
    vector-0.12.1.2-C2W44iPdAFeHo4yLU081Gd

haddock-interfaces:   /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html:         /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safecopy-0.10.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 safecopy
version:              0.10.3
visibility:           public
id:                   safecopy-0.10.3-5yphvuGCMgc5SAclfcC4B0
key:                  safecopy-0.10.3-5yphvuGCMgc5SAclfcC4B0
license:              LicenseRef-PublicDomain
maintainer:           Lemmih <lemmih@gmail.com>
author:               David Himmelstrup, Felipe Lessa
homepage:             https://github.com/acid-state/safecopy
synopsis:             Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.

category:             Data, Parsing
abi:                  f24cfb5bdaa1aa9411a013b495fc24e8
exposed:              True
exposed-modules:      Data.SafeCopy Data.SafeCopy.Internal
hidden-modules:
    Data.SafeCopy.Instances Data.SafeCopy.SafeCopy Data.SafeCopy.Derive

import-dirs:          /usr/lib/ghc-8.8.3/site-local/safecopy-0.10.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/safecopy-0.10.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/safecopy-0.10.3
hs-libraries:         HSsafecopy-0.10.3-5yphvuGCMgc5SAclfcC4B0
depends:
    array-0.5.4.0 base-4.13.0.0 bytestring-0.10.10.0
    cereal-0.5.8.1-4ELvUVAvdXS1XtXORHyQWs containers-0.6.2.1
    generic-data-0.8.3.0-iSJyI0ZQdF7gBCYe8hupn
    old-time-1.1.0.3-LFCo3WvTzIJ9XV4spupeM9 template-haskell-2.15.0.0
    text-1.2.4.0 time-1.9.3 transformers-0.5.6.2
    vector-0.12.1.2-C2W44iPdAFeHo4yLU081Gd

haddock-interfaces:   /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html:         /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
